@@ -20,21 +20,6 @@ def help_seed(
     )
 
 
-def help_set_ip(
-    tokens: List[str],
-    mono: bool,
-) -> str:
-    return show_usage(
-        [
-            "@arvan",
-            "set_ip",
-            "<ip-address>",
-        ],
-        "set arvancloud ip.",
-        mono=mono,
-    )
-
-
 def help_ssh(
     tokens: List[str],
     mono: bool,
@@ -46,14 +31,14 @@ def help_ssh(
             "@arvan",
             "ssh",
             f"[{options}]",
+            "<ip-address>",
         ],
-        "ssh -> arvancloud.",
+        "ssh to arvancloud.",
         mono=mono,
     )
 
 
 help_functions = {
     "seed": help_seed,
-    "set_ip": help_set_ip,
     "ssh": help_ssh,
 }
