@@ -6,6 +6,7 @@ from bluer_sandbox.help.notebooks import help_functions as help_notebooks
 from bluer_sandbox.help.offline_llm import help_functions as help_offline_llm
 from bluer_sandbox.help.parser import help_functions as help_offline_parser
 from bluer_sandbox.help.speedtest import help_speedtest
+from bluer_sandbox.help.tor import help_functions as help_tor
 
 from bluer_sandbox import ALIAS
 
@@ -21,5 +22,6 @@ help_functions.update(
         "offline_llm": help_offline_llm,
         "parser": help_offline_parser,
         "speedtest": help_speedtest,
+        "tor": help_tor,
     }
 )
